@@ -320,6 +320,7 @@ use anyhow::Context as _;
 
 use chrono::DateTime;
 use chrono::NaiveDate;
+use chrono::TimeZone;
 use chrono::Utc;
 
 use toml::value;
@@ -392,7 +393,7 @@ fn parse_time(t: &Value) -> Result<Timestamp> {
                 let t = NaiveDate::parse_from_str(t, "%Y-%m-%d")
                     .context(format!("Parsing timestamp {}", t))?
                     .and_hms_opt(0, 0, 0).expect("valid time");
-                let t: DateTime<Utc> = DateTime::from_utc(t, Utc);
+                let t: DateTime<Utc> = Utc.from_utc_datetime(&t);
                 t.into()
             };
 
@@ -476,17 +477,19 @@ const HASH_ALGO_PROPS: &[(&str, HashAlgoSecurity)] = &[
     ("collision_resistance", HashAlgoSecurity::CollisionResistance),
 ];
 
-const HASH_ALGO_MAP: [(&str, HashAlgorithm, &[(&str, HashAlgoSecurity)]); 7] = [
+const HASH_ALGO_MAP: [(&str, HashAlgorithm, &[(&str, HashAlgoSecurity)]); 9] = [
     ("md5", HashAlgorithm::MD5, HASH_ALGO_PROPS),
     ("sha1", HashAlgorithm::SHA1, HASH_ALGO_PROPS),
     ("ripemd160", HashAlgorithm::RipeMD, HASH_ALGO_PROPS),
     ("sha256", HashAlgorithm::SHA256, HASH_ALGO_PROPS),
     ("sha384", HashAlgorithm::SHA384, HASH_ALGO_PROPS),
     ("sha512", HashAlgorithm::SHA512, HASH_ALGO_PROPS),
-    ("sha224", HashAlgorithm::SHA224, HASH_ALGO_PROPS)
+    ("sha224", HashAlgorithm::SHA224, HASH_ALGO_PROPS),
+    ("sha3-256", HashAlgorithm::SHA3_256, HASH_ALGO_PROPS),
+    ("sha3-512", HashAlgorithm::SHA3_512, HASH_ALGO_PROPS),
 ];
 
-const ASYMM_ALGO_MAP: [(&str, AsymmetricAlgorithm, &[(&str, ())]); 19] = [
+const ASYMM_ALGO_MAP: [(&str, AsymmetricAlgorithm, &[(&str, ())]); 24] = [
     ("rsa1024", AsymmetricAlgorithm::RSA1024, &[]),
     ("rsa2048", AsymmetricAlgorithm::RSA2048, &[]),
     ("rsa3072", AsymmetricAlgorithm::RSA3072, &[]),
@@ -506,8 +509,14 @@ const ASYMM_ALGO_MAP: [(&str, AsymmetricAlgorithm, &[(&str, ())]); 19] = [
     ("brainpoolp384", AsymmetricAlgorithm::BrainpoolP384, &[]),
     ("brainpoolp512", AsymmetricAlgorithm::BrainpoolP512, &[]),
     ("cv25519", AsymmetricAlgorithm::Cv25519, &[]),
+    ("x25519", AsymmetricAlgorithm::X25519, &[]),
+    ("ed25519", AsymmetricAlgorithm::Ed25519, &[]),
+    ("x448", AsymmetricAlgorithm::X448, &[]),
+    ("ed448", AsymmetricAlgorithm::Ed448, &[]),
+    ("eddsa", AsymmetricAlgorithm::EdDSA, &[]),
 ];
 
+#[allow(deprecated)]
 const SYMM_ALGO_MAP: [(&str, SymmetricAlgorithm, &[(&str, ())]); 11] = [
     ("idea", SymmetricAlgorithm::IDEA, &[]),
     ("tripledes", SymmetricAlgorithm::TripleDES, &[]),
@@ -528,25 +537,26 @@ const AEAD_ALGO_MAP: [(&str, AEADAlgorithm, &[(&str, ())]); 3] = [
     ("gcm", AEADAlgorithm::GCM, &[]),
 ];
 
-const PACKET_MAP: [(&str, Tag, &[(&str, u8)]); 18] = [
-    ("pkesk", Tag::PKESK, &[("v3", 3)]),
-    ("signature", Tag::Signature, &[("v3", 3), ("v4", 4)]),
-    ("skesk", Tag::SKESK, &[("v4", 4)]),
-    ("onepasssig", Tag::OnePassSig, &[("v3", 3)]),
-    ("secretkey", Tag::SecretKey, &[("v4", 4)]),
-    ("publickey", Tag::PublicKey, &[("v4", 4)]),
-    ("secretsubkey", Tag::SecretSubkey, &[("v4", 4)]),
+const PACKET_MAP: [(&str, Tag, &[(&str, u8)]); 19] = [
+    ("pkesk", Tag::PKESK, &[("v3", 3), ("v5", 5), ("v6", 6)]),
+    ("signature", Tag::Signature, &[("v3", 3), ("v4", 4), ("v5", 5), ("v6", 6)]),
+    ("skesk", Tag::SKESK, &[("v4", 4), ("v5", 5), ("v6", 6)]),
+    ("onepasssig", Tag::OnePassSig, &[("v3", 3), ("v6", 6)]),
+    ("secretkey", Tag::SecretKey, &[("v4", 4), ("v5", 5), ("v6", 6)]),
+    ("publickey", Tag::PublicKey, &[("v4", 4), ("v5", 5), ("v6", 6)]),
+    ("secretsubkey", Tag::SecretSubkey, &[("v4", 4), ("v5", 5), ("v6", 6)]),
     ("compresseddata", Tag::CompressedData, &[]),
     ("sed", Tag::SED, &[]),
     ("marker", Tag::Marker, &[]),
     ("literal", Tag::Literal, &[]),
     ("trust", Tag::Trust, &[]),
     ("userid", Tag::UserID, &[]),
-    ("publicsubkey", Tag::PublicSubkey, &[("v4", 4)]),
+    ("publicsubkey", Tag::PublicSubkey, &[("v4", 4), ("v5", 5), ("v6", 6)]),
     ("userattribute", Tag::UserAttribute, &[]),
-    ("seip", Tag::SEIP, &[("v1", 1)]),
+    ("seip", Tag::SEIP, &[("v1", 1), ("v2", 2)]),
     ("mdc", Tag::MDC, &[]),
     ("aed", Tag::AED, &[("v1", 1)]),
+    ("padding", Tag::Padding, &[]),
 ];
 
 /// Given a map and an algorithm (or packet tag), returns the key
@@ -1425,8 +1435,7 @@ collision_resistance = \"{}\"
                     id, time.0)).expect("valid");
                 let p = p.build();
 
-                #[allow(deprecated)]
-                let cutoff = p.packet_tag_cutoff(algo.clone());
+                let cutoff = p.packet_tag_version_cutoff(algo, 1);
                 assert_eq!(
                     cutoff, time.1,
                     "algo: {}, t: {}", id, time.0);
@@ -1471,6 +1480,7 @@ collision_resistance = \"{}\"
 
     /// Check a simple config file.
     #[test]
+    #[allow(deprecated)]
     fn simple_config() -> Result<()> {
         // Something simple.
         let mut p = ConfiguredStandardPolicy::new();
@@ -1587,8 +1597,7 @@ aes256 = \"2050-01-01\"
         for (_, algo, props) in PACKET_MAP {
             let d = ts(&date());
 
-            #[allow(deprecated)]
-            let cutoff = p.packet_tag_cutoff(algo);
+            let cutoff = p.packet_tag_version_cutoff(algo, 1);
             assert_eq!(cutoff, d);
 
             // Setting the default means it should apply to all
@@ -1712,8 +1721,7 @@ default_disposition = \"never\"
             assert_eq!(p.aead_algo_cutoff(algo.into()), Some(UNIX_EPOCH));
         }
         for algo in 0..=u8::MAX {
-            #[allow(deprecated)]
-            let cutoff = p.packet_tag_cutoff(algo.into());
+            let cutoff = p.packet_tag_version_cutoff(algo.into(), 1);
             assert_eq!(cutoff, Some(UNIX_EPOCH));
         }
         for (_, algo, props) in PACKET_MAP {
@@ -1805,8 +1813,7 @@ default_disposition = \"never\"
 
         for algo in 0..=u8::MAX {
             let algo = Tag::from(algo);
-            #[allow(deprecated)]
-            let cutoff = p.packet_tag_cutoff(algo.into());
+            let cutoff = p.packet_tag_version_cutoff(algo.into(), 1);
             if algo == Tag::SEIP {
                 assert_eq!(cutoff, ALWAYS);
             } else {
