@@ -2,12 +2,12 @@
 //!
 //! This module includes the test data from `tests/data` in a
 //! structured way.
+#![allow(unused)]
 
 use std::fmt;
 use std::collections::BTreeMap;
 use std::path::PathBuf;
-
-use lazy_static::lazy_static;
+use std::sync::OnceLock;
 
 pub struct Test {
     path: &'static str,
@@ -27,24 +27,23 @@ pub fn dir() -> PathBuf {
 
 /// Returns the content of the given file below `keystore/tests/data`.
 pub fn file(name: &str) -> &'static [u8] {
-    lazy_static! {
-        static ref FILES: BTreeMap<&'static str, &'static [u8]> = {
-            let mut m: BTreeMap<&'static str, &'static [u8]> =
-                Default::default();
+    static FILES: OnceLock<BTreeMap<&'static str, &'static [u8]>> =
+        OnceLock::new();
 
-            macro_rules! add {
-                ( $key: expr, $path: expr ) => {
-                    m.insert($key, include_bytes!($path))
-                }
+    FILES.get_or_init(|| {
+        let mut m: BTreeMap<&'static str, &'static [u8]> =
+            Default::default();
+
+        macro_rules! add {
+            ( $key: expr, $path: expr ) => {
+                m.insert($key, include_bytes!($path))
             }
-            include!(concat!(env!("OUT_DIR"), "/tests.index.rs.inc"));
+        }
+        include!(concat!(env!("OUT_DIR"), "/tests.index.rs.inc"));
 
-            // Sanity checks.
-            assert!(m.contains_key("alice-secret.asc"));
-            m
-        };
-    }
-
-    FILES.get(name).unwrap_or_else(|| panic!("No such file {:?}", name))
+        // Sanity checks.
+        assert!(m.contains_key("alice-secret.asc"));
+        m
+    }).get(name).unwrap_or_else(|| panic!("No such file {:?}", name))
 }
 
